@@ -25,7 +25,7 @@ describe 'vitrage::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-vitrageclient' }
         when 'RedHat'
