@@ -87,7 +87,7 @@ describe 'vitrage::notifier' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
           when 'Debian'
             { :notifier_package_name => 'vitrage-notifier',
               :notifier_service_name => 'vitrage-notifier' }
