@@ -10,7 +10,7 @@ describe 'vitrage::wsgi::apache' do
         :group                       => 'vitrage',
         :path                        => '/',
         :priority                    => 10,
-        :servername                  => facts[:fqdn],
+        :servername                  => 'foo.example.com',
         :ssl                         => false,
         :threads                     => 1,
         :user                        => 'vitrage',
@@ -145,18 +145,16 @@ describe 'vitrage::wsgi::apache' do
     context "on #{os}" do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
-          :os_workers     => 8,
-          :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld'
+          :os_workers => 8,
         }))
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :wsgi_script_path   => '/usr/lib/cgi-bin/vitrage',
-            :wsgi_script_source => '/usr/share/vitrage-common/app.wsgi'
+            :wsgi_script_source => '/usr/lib/python3/dist-packages/vitrage/api/app.wsgi'
           }
         when 'RedHat'
           {
